@@ -72,6 +72,11 @@ const Vector<StringC> *DeclaredValue::getTokens() const
   return 0;
 }
 
+const Vector<StringC> *DeclaredValue::getOrigTokens() const
+{
+  return 0;
+}
+
 
 CdataDeclaredValue::CdataDeclaredValue()
 {
@@ -329,6 +334,7 @@ GroupDeclaredValue::GroupDeclaredValue(TokenType type,
 void GroupDeclaredValue::buildDesc(AttributeDefinitionDesc &desc) const
 {
   desc.allowedValues = allowedValues_;
+  desc.origAllowedValues = origAllowedValues_;
 }
 
 DeclaredValue *GroupDeclaredValue::copy() const
@@ -336,6 +342,11 @@ DeclaredValue *GroupDeclaredValue::copy() const
   return new GroupDeclaredValue(*this);
 }
 
+void GroupDeclaredValue::setOrigAllowedValues(Vector<StringC> &origAllowedValues)
+{
+  origAllowedValues.swap(origAllowedValues_);
+}
+
 AttributeValue *GroupDeclaredValue::makeValue(Text &text,
 					      AttributeContext &context,
 					      const StringC &name,
@@ -385,6 +396,11 @@ const Vector<StringC> *GroupDeclaredValue::getTokens() const
   return &allowedValues_;
 }
 
+const Vector<StringC> *GroupDeclaredValue::getOrigTokens() const
+{
+  return &origAllowedValues_;
+}
+
 NameTokenGroupDeclaredValue::NameTokenGroupDeclaredValue(Vector<StringC> &vec)
 : GroupDeclaredValue(nameToken, vec)
 {
@@ -588,6 +604,12 @@ Boolean AttributeDefinition::isSpecified(Boolean &implicit)
   return implicit_ || all_;
 }
 
+void AttributeDefinition::setOrigName(StringC &origName)
+{
+  if (&origName != NULL)
+    origName.swap(origName_);
+}
+
 AttributeDefinition::~AttributeDefinition()
 {
 }
